@@ -15,6 +15,10 @@
 #  You should have received a copy of the GNU General Public License
 #  along with ARA.  If not, see <http://www.gnu.org/licenses/>.
 
+import datetime
+
+from django.utils import timezone
+from django.utils.dateparse import parse_duration
 from rest_framework.test import APITestCase
 
 from ara.api import models, serializers
@@ -179,3 +183,51 @@ class ResultTestCase(APITestCase):
         unreachable = factories.ResultFactory(status="unreachable")
         result = self.client.get("/api/v1/results/%s" % unreachable.id)
         self.assertEqual(result.data["status"], "unreachable")
+
+    def test_get_result_duration(self):
+        started = timezone.now()
+        ended = started + datetime.timedelta(hours=1)
+        result = factories.ResultFactory(started=started, ended=ended)
+        request = self.client.get("/api/v1/results/%s" % result.id)
+        self.assertEqual(parse_duration(request.data["duration"]), ended - started)
+
+    def test_get_result_by_date(self):
+        result = factories.ResultFactory()
+
+        past = datetime.datetime.now() - datetime.timedelta(hours=12)
+        negative_date_fields = ["created_before", "started_before", "updated_before"]
+        positive_date_fields = ["created_after", "started_after", "updated_after"]
+
+        # Expect no result when searching before it was created
+        for field in negative_date_fields:
+            request = self.client.get("/api/v1/results?%s=%s" % (field, past.isoformat()))
+            self.assertEqual(request.data["count"], 0)
+
+        # Expect a result when searching after it was created
+        for field in positive_date_fields:
+            request = self.client.get("/api/v1/results?%s=%s" % (field, past.isoformat()))
+            self.assertEqual(request.data["count"], 1)
+            self.assertEqual(request.data["results"][0]["id"], result.id)
+
+    def test_get_result_order(self):
+        old_started = timezone.now() - datetime.timedelta(hours=12)
+        old_ended = old_started + datetime.timedelta(minutes=30)
+        old_result = factories.ResultFactory(started=old_started, ended=old_ended)
+        new_started = timezone.now() - datetime.timedelta(hours=6)
+        new_ended = new_started + datetime.timedelta(hours=1)
+        new_result = factories.ResultFactory(started=new_started, ended=new_ended)
+
+        # Ensure we have two objects
+        request = self.client.get("/api/v1/results")
+        self.assertEqual(2, len(request.data["results"]))
+
+        order_fields = ["id", "created", "updated", "started", "ended", "duration"]
+        # Ascending order
+        for field in order_fields:
+            request = self.client.get("/api/v1/results?order=%s" % field)
+            self.assertEqual(request.data["results"][0]["id"], old_result.id)
+
+        # Descending order
+        for field in order_fields:
+            request = self.client.get("/api/v1/results?order=-%s" % field)
+            self.assertEqual(request.data["results"][0]["id"], new_result.id)
