@@ -87,6 +87,15 @@ options:
     ini:
       - section: ara
         key: api_password
+  api_insecure:
+    description: Can be enabled to ignore SSL certification of the API server
+    type: bool
+    default: false
+    env:
+      - name: ARA_API_INSECURE
+    ini:
+      - section: ara
+        key: api_insecure
   api_timeout:
     description: Timeout, in seconds, before giving up on HTTP requests
     type: integer
@@ -139,6 +148,8 @@ class CallbackModule(CallbackBase):
         self.playbook = None
         self.stats = None
         self.loop_items = []
+        self.file_cache = {}
+        self.host_cache = {}
 
     def set_options(self, task_keys=None, var_options=None, direct=None):
         super(CallbackModule, self).set_options(task_keys=task_keys, var_options=var_options, direct=direct)
@@ -151,8 +162,14 @@ class CallbackModule(CallbackBase):
         timeout = self.get_option("api_timeout")
         username = self.get_option("api_username")
         password = self.get_option("api_password")
+        insecure = self.get_option("api_insecure")
         self.client = client_utils.get_client(
-            client=client, endpoint=endpoint, timeout=timeout, username=username, password=password
+            client=client,
+            endpoint=endpoint,
+            timeout=timeout,
+            username=username,
+            password=password,
+            verify=False if insecure else True,
         )
 
     def v2_playbook_on_start(self, playbook):
@@ -167,7 +184,12 @@ class CallbackModule(CallbackBase):
 
         # Create the playbook
         self.playbook = self.client.post(
-            "/api/v1/playbooks", ansible_version=ansible_version, arguments=cli_options, status="running", path=path
+            "/api/v1/playbooks",
+            ansible_version=ansible_version,
+            arguments=cli_options,
+            status="running",
+            path=path,
+            started=datetime.datetime.now().isoformat(),
         )
 
         # Record the playbook file
@@ -193,13 +215,14 @@ class CallbackModule(CallbackBase):
 
         # Create the play
         self.play = self.client.post(
-            "/api/v1/plays", name=play.name, status="running", uuid=play._uuid, playbook=self.playbook["id"]
+            "/api/v1/plays",
+            name=play.name,
+            status="running",
+            uuid=play._uuid,
+            playbook=self.playbook["id"],
+            started=datetime.datetime.now().isoformat(),
         )
 
-        # Record all the hosts involved in the play
-        for host in play.hosts:
-            self._get_or_create_host(host=host)
-
         return self.play
 
     def v2_playbook_on_task_start(self, task, is_conditional, handler=False):
@@ -229,6 +252,7 @@ class CallbackModule(CallbackBase):
             tags=task.tags,
             lineno=lineno,
             handler=handler,
+            started=datetime.datetime.now().isoformat(),
         )
 
         return self.task
@@ -287,22 +311,28 @@ class CallbackModule(CallbackBase):
             self.playbook = self.client.patch("/api/v1/playbooks/%s" % self.playbook["id"], labels=labels)
 
     def _get_or_create_file(self, path):
-        self.log.debug("Getting or creating file: %s" % path)
-        # Note: The get_or_create is handled through the serializer of the API server.
-        try:
-            with open(path, "r") as fd:
-                content = fd.read()
-        except IOError as e:
-            self.log.error("Unable to open {0} for reading: {1}".format(path, six.text_type(e)))
-            content = """ARA was not able to read this file successfully.
-                      Refer to the logs for more information"""
+        if path not in self.file_cache:
+            self.log.debug("File not in cache, getting or creating: %s" % path)
+            try:
+                with open(path, "r") as fd:
+                    content = fd.read()
+            except IOError as e:
+                self.log.error("Unable to open {0} for reading: {1}".format(path, six.text_type(e)))
+                content = """ARA was not able to read this file successfully.
+                        Refer to the logs for more information"""
 
-        return self.client.post("/api/v1/files", playbook=self.playbook["id"], path=path, content=content)
+            self.file_cache[path] = self.client.post(
+                "/api/v1/files", playbook=self.playbook["id"], path=path, content=content
+            )
+
+        return self.file_cache[path]
 
     def _get_or_create_host(self, host):
-        self.log.debug("Getting or creating host: %s" % host)
         # Note: The get_or_create is handled through the serializer of the API server.
-        return self.client.post("/api/v1/hosts", name=host, playbook=self.playbook["id"])
+        if host not in self.host_cache:
+            self.log.debug("Host not in cache, getting or creating: %s" % host)
+            self.host_cache[host] = self.client.post("/api/v1/hosts", name=host, playbook=self.playbook["id"])
+        return self.host_cache[host]
 
     def _load_result(self, result, status, **kwargs):
         """
@@ -310,6 +340,7 @@ class CallbackModule(CallbackBase):
         host completes. It is responsible for logging a single result to the
         database.
         """
+        # Retrieve the host so we can associate the result to the host id
         host = self._get_or_create_host(result._host.get_name())
 
         # Use Ansible's CallbackBase._dump_results in order to strip internal
@@ -342,7 +373,7 @@ class CallbackModule(CallbackBase):
             ignore_errors=kwargs.get("ignore_errors", False) or False,
         )
 
-        if self.task["action"] == "setup" and "ansible_facts" in results:
+        if self.task["action"] in ["setup", "gather_facts"] and "ansible_facts" in results:
             # Potentially sanitize some Ansible facts to prevent them from
             # being saved both in the host facts and in the task results.
             for fact in self.ignored_facts:
