@@ -21,7 +21,7 @@ import sys
 
 from django.conf import settings
 
-from ara.setup.exceptions import MissingDjangoException
+from ara.setup.exceptions import MissingDjangoException, MissingMysqlclientException, MissingPsycopgException
 
 
 def main():
@@ -32,8 +32,20 @@ def main():
     except ImportError as e:
         raise MissingDjangoException from e
 
+    if settings.DATABASE_ENGINE == "django.db.backends.postgresql":
+        try:
+            import psycopg2  # noqa
+        except ImportError as e:
+            raise MissingPsycopgException from e
+
+    if settings.DATABASE_ENGINE == "django.db.backends.mysql":
+        try:
+            import MySQLdb  # noqa
+        except ImportError as e:
+            raise MissingMysqlclientException from e
+
     execute_from_command_line(sys.argv)
-    print(f"[ara] Using settings file: {settings.ARA_SETTINGS}")
+    print("[ara] Using settings file: %s" % settings.ARA_SETTINGS)
 
 
 if __name__ == "__main__":
