@@ -19,6 +19,7 @@ import os
 import textwrap
 import warnings
 
+import tzlocal
 import yaml
 from django.utils.crypto import get_random_string
 from dynaconf import LazySettings
@@ -69,6 +70,7 @@ LOGGING = {
 # Django built-in server and npm development server
 ALLOWED_HOSTS = settings.get("ALLOWED_HOSTS", ["::1", "127.0.0.1", "localhost"])
 CORS_ORIGIN_WHITELIST = settings.get("CORS_ORIGIN_WHITELIST", ["http://127.0.0.1:8000", "http://localhost:3000"])
+CORS_ORIGIN_REGEX_WHITELIST = settings.get("CORS_ORIGIN_REGEX_WHITELIST", [])
 CORS_ORIGIN_ALLOW_ALL = settings.get("CORS_ORIGIN_ALLOW_ALL", False)
 
 ADMINS = settings.get("ADMINS", ())
@@ -91,12 +93,12 @@ SECRET_KEY = get_secret_key()
 DISTRIBUTED_SQLITE = settings.get("DISTRIBUTED_SQLITE", False)
 
 # Under which URL should requests be delegated to the distributed sqlite wsgi application
-DISTRIBUTED_SQLITE_PREFIX = settings.get("DISTRIBUTED_SQLITE_PREFIX", "ara-api")
+DISTRIBUTED_SQLITE_PREFIX = settings.get("DISTRIBUTED_SQLITE_PREFIX", "ara-report")
 
 # Root directory under which databases will be found relative to the requested URLs.
 # This will restrict where the WSGI application will go to seek out databases.
-# For example, the URL "example.org/some/path/ara-api" would translate to
-# "/var/www/logs/some/path/ara-api" instead of "/some/path/ara-api".
+# For example, the URL "example.org/some/path/ara-report" would translate to
+# "/var/www/logs/some/path/ara-report" instead of "/some/path/ara-report".
 DISTRIBUTED_SQLITE_ROOT = settings.get("DISTRIBUTED_SQLITE_ROOT", "/var/www/logs")
 
 if DISTRIBUTED_SQLITE:
@@ -134,10 +136,13 @@ INSTALLED_APPS = [
     "django.contrib.sessions",
     "django.contrib.messages",
     "django.contrib.staticfiles",
+    "health_check",
+    "health_check.db",
     "corsheaders",
     "rest_framework",
     "django_filters",
     "ara.api",
+    "ara.ui",
     "ara.server.apps.AraAdminConfig",
 ]
 
@@ -185,7 +190,8 @@ AUTH_PASSWORD_VALIDATORS = [
 ]
 
 USE_TZ = True
-TIME_ZONE = "UTC"
+LOCAL_TIME_ZONE = tzlocal.get_localzone().zone
+TIME_ZONE = settings.get("TIME_ZONE", LOCAL_TIME_ZONE)
 
 # We do not currently support internationalization and localization, turn these
 # off.
@@ -224,6 +230,7 @@ REST_FRAMEWORK = {
     "DEFAULT_AUTHENTICATION_CLASSES": ("rest_framework.authentication.BasicAuthentication",),
     "DEFAULT_PERMISSION_CLASSES": ("ara.api.auth.APIAccessPermission",),
     "TEST_REQUEST_DEFAULT_FORMAT": "json",
+    "UNICODE_JSON": False,
 }
 
 ARA_SETTINGS = os.getenv("ARA_SETTINGS", DEFAULT_SETTINGS)
@@ -232,7 +239,7 @@ ARA_SETTINGS = os.getenv("ARA_SETTINGS", DEFAULT_SETTINGS)
 
 # Ensure default base configuration/data directory exists
 if not os.path.isdir(BASE_DIR):
-    print(f"[ara] Creating data & configuration directory: {BASE_DIR}")
+    print("[ara] Creating data & configuration directory: %s" % BASE_DIR)
     os.makedirs(BASE_DIR, mode=0o700)
 
 if not os.path.exists(DEFAULT_SETTINGS) and "ARA_SETTINGS" not in os.environ:
@@ -240,6 +247,7 @@ if not os.path.exists(DEFAULT_SETTINGS) and "ARA_SETTINGS" not in os.environ:
         BASE_DIR=BASE_DIR,
         ALLOWED_HOSTS=ALLOWED_HOSTS,
         CORS_ORIGIN_WHITELIST=CORS_ORIGIN_WHITELIST,
+        CORS_ORIGIN_REGEX_WHITELIST=CORS_ORIGIN_REGEX_WHITELIST,
         CORS_ORIGIN_ALLOW_ALL=CORS_ORIGIN_ALLOW_ALL,
         SECRET_KEY=SECRET_KEY,
         DATABASE_ENGINE=DATABASE_ENGINE,
@@ -258,16 +266,21 @@ if not os.path.exists(DEFAULT_SETTINGS) and "ARA_SETTINGS" not in os.environ:
         DISTRIBUTED_SQLITE=DISTRIBUTED_SQLITE,
         DISTRIBUTED_SQLITE_PREFIX=DISTRIBUTED_SQLITE_PREFIX,
         DISTRIBUTED_SQLITE_ROOT=DISTRIBUTED_SQLITE_ROOT,
+        TIME_ZONE=TIME_ZONE,
     )
     with open(DEFAULT_SETTINGS, "w+") as settings_file:
-        comment = f"""
-        ---
-        # This is a default settings template generated by ARA.
-        # To use a settings file such as this one, you need to export the
-        # ARA_SETTINGS environment variable like so:
-        #   $ export ARA_SETTINGS="{DEFAULT_SETTINGS}"
+        comment = textwrap.dedent(
+            """
+            ---
+            # This is a default settings template generated by ARA.
+            # To use a settings file such as this one, you need to export the
+            # ARA_SETTINGS environment variable like so:
+            #   $ export ARA_SETTINGS="{}"
 
-        """
-        print(f"[ara] Writing default settings to {DEFAULT_SETTINGS}")
-        settings_file.write(textwrap.dedent(comment))
+            """.format(
+                DEFAULT_SETTINGS
+            )
+        )
+        print("[ara] Writing default settings to %s" % DEFAULT_SETTINGS)
+        settings_file.write(comment.lstrip())
         yaml.dump({"default": SETTINGS}, settings_file, default_flow_style=False)
